/*
 * TELNET Server
 *
 * Copyright (c) 1990, 1999 Erick Engelke
 */

#include <net.h>

#define TELNETPORT 23

typedef struct {
    tcp_Socket teld_socket;
    int        teld_connected;
    int        teld_iostate;

} teld_str;

teld_str *teld_listen( int port );
int teld_write( teld_str *t, char *buffer, int len );
int teld_puts( teld_str *t, char *s );
char teld_putch( teld_str *t, char x );
BYTE teld_getc( teld_str *t );
int teld_iswaiting( teld_str *t );
char *teld_gets( teld_str *t, char *buf, int maxlen, long timeout );
void teld_close( teld_str *t );
char *teld_getpassword( teld_str *t, char *buf, int maxlen, long timeout );
char *teld_getstring( teld_str *t, char *buf, int maxlen, long timeout, char dispchar );



